@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-# © Toons
 
 import os
 import getpass
@@ -7,6 +6,7 @@ import dposlib
 
 from dposlib.util.data import filter_dic, dumpJson
 from dposlib.ark.v2.mixin import loadPages, deltas
+from dposlib.ark.tx import serialize
 try:
     from dposlib.ark import ldgr
     LEDGERBLUE = True
@@ -17,125 +17,121 @@ deltas = deltas
 GET = dposlib.rest.GET
 
 
-class Wallet(dposlib.blockchain.Wallet):
-    # TODO: add transactions 5 - 10
-    delegate = property(
-        lambda cls: Delegate(cls.username) if cls.isDelegate else None,
-        None, None, ""
-    )
+class Wallet(dposlib.ark.Wallet):
 
     def __init__(self, address, **kw):
-        dposlib.blockchain.Wallet.__init__(
+        dposlib.ark.Wallet.__init__(
             self, GET.api.wallets, address, **dict({"returnKey": "data"}, **kw)
         )
 
-    def transactions(self, limit=50):
-        sent = loadPages(
-            GET.api.wallets.__getattr__(self.address).transactions.sent,
-            limit=limit
-        )
-        received = loadPages(
-            GET.api.wallets.__getattr__(self.address).transactions.received,
-            limit=limit
-        )
-        return [
-            filter_dic(dic) for dic in sorted(
-                received+sent,
-                key=lambda e: e.get("timestamp", {}).get("epoch"),
-                reverse=True
-            )
-        ][:limit]
-
-    @dposlib.blockchain.Data.wallet_islinked
-    def registerIpfs(self, ipfs):
-        "See :func:`dposlib.ark.v2.registerIpfs`."
+    @dposlib.ark.isLinked
+    def sendIpfs(self, ipfs):
+        "See [`dposlib.ark.v2.registerIpfs`](v2.md#registeripfs)."
         tx = dposlib.core.registerIpfs(ipfs)
         return dposlib.core.broadcastTransactions(self._finalizeTx(tx))
 
-    @dposlib.blockchain.Data.wallet_islinked
+    @dposlib.ark.isLinked
     def multiSend(self, *pairs, **kwargs):
-        "See :func:`dposlib.ark.v2.multiPayment`."
+        "See [`dposlib.ark.v2.multiPayment`](v2.md#multipayment)."
         tx = dposlib.core.multiPayment(*pairs, **kwargs)
         return dposlib.core.broadcastTransactions(self._finalizeTx(tx))
 
-    @dposlib.blockchain.Data.wallet_islinked
+    @dposlib.ark.isLinked
     def resignate(self):
-        "See :func:`dposlib.ark.v2.delegateResignation`."
+        """
+        See [`dposlib.ark.v2.delegateResignation`](v2.md#delegateresignation).
+        """
         tx = dposlib.core.delegateResignation()
         return dposlib.core.broadcastTransactions(self._finalizeTx(tx))
 
-    @dposlib.blockchain.Data.wallet_islinked
+    @dposlib.ark.isLinked
     def sendHtlc(self, amount, address, secret,
                  expiration=24, vendorField=None):
-        "See :func:`dposlib.ark.v2.htlcLock`."
+        "See [`dposlib.ark.v2.htlcLock`](v2.md#htlclock)."
         tx = dposlib.core.htlcLock(
             amount, address, secret,
             expiration=expiration, vendorField=vendorField
         )
         return dposlib.core.broadcastTransactions(self._finalizeTx(tx))
 
-    @dposlib.blockchain.Data.wallet_islinked
+    @dposlib.ark.isLinked
     def claimHtlc(self, txid, secret):
-        "See :func:`dposlib.ark.v2.htlcClaim`."
+        "See [`dposlib.ark.v2.htlcClaim`](v2.md#htlcclaim)."
         tx = dposlib.core.htlcClaim(txid, secret)
         return dposlib.core.broadcastTransactions(self._finalizeTx(tx))
 
-    @dposlib.blockchain.Data.wallet_islinked
+    @dposlib.ark.isLinked
     def refundHtlc(self, txid):
-        "See :func:`dposlib.ark.v2.htlcRefund`."
+        "See [`dposlib.ark.v2.htlcRefund`](v2.md#htlcrefund)."
         tx = dposlib.core.htlcRefund(txid)
         return dposlib.core.broadcastTransactions(self._finalizeTx(tx))
 
 
 if LEDGERBLUE:
-    class NanoS(Wallet):
 
-        def __init__(self, account, index, network=1, **kw):
+    class Ledger(Wallet):
+        """
+        Ledger wallet api.
+        """
+
+        def __init__(self, account, index, network=0, **kw):
+            self._debug = kw.pop("debug", False)
+            self._schnorr = kw.pop("schnorr", True)
             # aip20 : https://github.com/ArkEcosystem/AIPs/issues/29
-            self.derivationPath = "44'/%s'/%s'/%s'/%s" % (
-                dposlib.rest.cfg.slip44,
+            self._derivationPath = "44'/%s'/%s'/%s/%s" % (
+                getattr(dposlib.rest.cfg, "slip44", "111"),
                 getattr(dposlib.rest.cfg, "aip20", network),
                 account,
                 index
             )
-            self.address = dposlib.core.crypto.getAddress(
-                ldgr.getPublicKey(ldgr.parseBip32Path(self.derivationPath))
+            self._dongle_path = ldgr.parseBip44Path(self._derivationPath)
+            puk = ldgr.sendApdu(
+                [ldgr.buildPukApdu(self._dongle_path)], debug=self._debug
+            )[2:]
+            object.__setattr__(self, "publicKey", puk)
+            object.__setattr__(
+                self, "address", dposlib.core.crypto.getAddress(puk)
             )
-            self.debug = kw.pop("debug", False)
             Wallet.__init__(self, self.address, **kw)
 
         @staticmethod
         def fromDerivationPath(derivationPath, **kw):
-            nanos = NanoS(0, 0, 0, **kw)
-            address = dposlib.core.crypto.getAddress(
-                ldgr.getPublicKey(ldgr.parseBip32Path(derivationPath))
+            ldgr_wlt = Ledger(0, 0, 0, **kw)
+            ldgr_wlt._derivationPath = derivationPath
+            ldgr_wlt._dongle_path = ldgr.parseBip44Path(derivationPath)
+            puk = ldgr.sendApdu(
+                [ldgr.buildPukApdu(ldgr_wlt._dongle_path)],
+                debug=ldgr_wlt._debug
+            )[2:]
+            object.__setattr__(ldgr_wlt, "publicKey", puk)
+            object.__setattr__(
+                ldgr_wlt, "address", dposlib.core.crypto.getAddress(puk)
             )
-            nanos.address = address
-            nanos.derivationPath = derivationPath
-            nanos._Data__args = (address,)
-            nanos.update()
-            return nanos
+            ldgr_wlt._Content__args = (ldgr_wlt.address,)
+            ldgr_wlt.update()
+            return ldgr_wlt
 
-        def _finalizeTx(self, tx, fee=None, fee_included=False):
-            if "fee" not in tx or fee is not None:
-                tx.setFees(fee)
-            tx.feeIncluded() if fee_included else tx.feeExcluded()
+        def _finalizeTx(self, tx):
+            if "fee" not in tx or self._fee is not None:
+                tx.fee = self._fee
+            tx.feeIncluded = self._fee_included
+            tx["senderPublicKey"] = self.publicKey
+            tx["signature"] = ldgr.sendApdu(
+                ldgr.buildSignatureApdu(
+                    serialize(tx),
+                    self._dongle_path,
+                    "tx",
+                    self._schnorr
+                ),
+                debug=self._debug
+            )
 
-            tx["senderId"] = self.address
-            if tx["type"] in [1, 3, 4] and "recipientId" not in tx:
-                tx["recipientId"] = self.address
-
-            try:
-                ldgr.signTransaction(tx, self.derivationPath, self.debug)
-            except ldgr.ledgerblue.commException.CommException:
-                raise Exception("transaction cancelled")
-
-            if self.secondPublicKey is not None:
+            if tx._secondPublicKey is not None:
                 try:
                     k2 = dposlib.core.crypto.getKeys(
                         getpass.getpass("second secret > ")
                     )
-                    while k2.get("publicKey", None) != self.secondPublicKey:
+                    while k2.get("publicKey", None) != tx._secondPublicKey:
                         k2 = dposlib.core.crypto.getKeys(
                             getpass.getpass("second secret > ")
                         )
@@ -150,7 +146,7 @@ if LEDGERBLUE:
             return tx
 
 
-class Delegate(dposlib.blockchain.Data):
+class Delegate(dposlib.ark.Content):
 
     wallet = property(lambda cls: Wallet(cls.address), None, None, "")
     voters = property(
@@ -169,7 +165,7 @@ class Delegate(dposlib.blockchain.Data):
     )
 
     def __init__(self, username, **kw):
-        dposlib.blockchain.Data.__init__(
+        dposlib.ark.Content.__init__(
             self, GET.api.delegates, username,
             **dict({"returnKey": "data"}, **kw)
         )
@@ -181,7 +177,7 @@ class Delegate(dposlib.blockchain.Data):
         )
 
 
-class Block(dposlib.blockchain.Data):
+class Block(dposlib.ark.Content):
 
     previous = property(
         lambda cls: Block(cls._Data__dict["previous"]),
@@ -198,12 +194,13 @@ class Block(dposlib.blockchain.Data):
     )
 
     def __init__(self, blk_id, **kw):
-        dposlib.blockchain.Data.__init__(
+        dposlib.ark.Content.__init__(
             self, GET.api.blocks, blk_id, **dict({"returnKey": "data"}, **kw)
         )
 
 
-class Webhook(dposlib.blockchain.Data):
+# TODO: redefine
+class Webhook(dposlib.ark.Content):
 
     @staticmethod
     def create(peer, event, target, conditions):
@@ -220,7 +217,7 @@ class Webhook(dposlib.blockchain.Data):
         return Webhook(data["id"], peer=peer)
 
     def __init__(self, whk_id, **kw):
-        dposlib.blockchain.Data.__init__(
+        dposlib.ark.Content.__init__(
             self, GET.api.webhooks, "%s" % whk_id,
             **dict({"track": False, "returnKey": "data"}, **kw)
         )
