@@ -1,18 +1,17 @@
 # -*- coding: utf-8 -*-
-# © Toons
 
 import datetime
 from collections import OrderedDict
 
 import pytz
 from dposlib import rest
-from dposlib.blockchain import slots
+from dposlib.ark import slots
 
 
 class DataIterator:
 
     def __init__(self, endpoint, tries=10):
-        if not isinstance(endpoint, rest.EndPoint):
+        if not isinstance(endpoint, rest.GET.__class__):
             raise Exception("Invalid endpoint class")
         self.endpoint = endpoint
         self.data = {}
