@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
-# © Toons
 
 import unittest
 import dposlib
 import os
 
 from dposlib import rest
-from dposlib import blockchain
+from dposlib.ark import tx as tx_
 from dposlib.util import bin as bin_
 from dposlib.util import data
 
@@ -31,9 +30,12 @@ class TestArkAip11(unittest.TestCase):
             serialized = tx.pop("serialized", False)
             id_ = tx.pop("id", False)
             sig = tx.pop("signature", False)
-            t = blockchain.Transaction(tx)
+            t = tx_.Transaction(tx)
             t.signature = sig
-            computed = bin_.hexlify(dposlib.core.crypto.getBytes(t,
-                                    exclude_multi_sig=not t['type'] == 4))
-            self.assertEqual(serialized, computed)
+            computed = bin_.hexlify(
+                dposlib.core.crypto.getBytes(
+                    t, exclude_multi_sig=not t['type'] == 4
+                )
+            )
+            self.assertEqual(str(serialized), computed)
             self.assertEqual(id_, dposlib.core.crypto.getId(t))
